==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01GatewayHTTPRoute,ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder>{
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01GatewayHTTPRoute(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01GatewayHTTPRoute(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent,ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent,ACMEChallengeSolverHTTP01GatewayHTTPRoute instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01GatewayHTTPRoute());

    if (instance != null) {
      fluent.withLabels(instance.getLabels());
      fluent.withServiceType(instance.getServiceType());
      fluent.withLabels(instance.getLabels());
      fluent.withServiceType(instance.getServiceType());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRoute instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01GatewayHTTPRoute());

    if (instance != null) {
      this.withLabels(instance.getLabels());
      this.withServiceType(instance.getServiceType());
      this.withLabels(instance.getLabels());
      this.withServiceType(instance.getServiceType());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute build() {
    ACMEChallengeSolverHTTP01GatewayHTTPRoute buildable = new ACMEChallengeSolverHTTP01GatewayHTTPRoute(fluent.getLabels(),fluent.getServiceType());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.10.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01GatewayHTTPRoute,ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder>{
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder() {
    this(new ACMEChallengeSolverHTTP01GatewayHTTPRoute());
  }
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent) {
    this(fluent, new ACMEChallengeSolverHTTP01GatewayHTTPRoute());
  }
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent,ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(ACMEChallengeSolverHTTP01GatewayHTTPRoute instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<?> fluent;
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute build() {
    ACMEChallengeSolverHTTP01GatewayHTTPRoute buildable = new ACMEChallengeSolverHTTP01GatewayHTTPRoute(fluent.getLabels(),fluent.getServiceType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
